==> Spire.Pdf-9.12.0-py3-none-win_amd64.whl: spire/pdf/PdfFileInfo.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfFileInfo(SpireObject):
    """
    This class represents a set of the properties that define the internal structure of PDF file.
    """

    @property
    def Version(self) -> 'PdfVersion':
        """
        Gets or sets the version of the PDF document.
        :return: The document version.
        """
        GetDllLibPdf().PdfFileInfo_get_Version.argtypes = [c_void_p]
        GetDllLibPdf().PdfFileInfo_get_Version.restype = c_int
        ret = GetDllLibPdf().PdfFileInfo_get_Version(self.Ptr)
        objwrapped = PdfVersion(ret)
        return objwrapped

    @Version.setter
    def Version(self, value: 'PdfVersion'):
        """
        Sets the version of the PDF document.
        :param value: The document version.
        """
        GetDllLibPdf().PdfFileInfo_set_Version.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfFileInfo_set_Version(self.Ptr, value.value)

    @property
    def IncrementalUpdate(self) -> bool:
        """
        Gets or sets a value indicating whether [incremental update].
        :return: True if [incremental update]; otherwise, False.
        """
        GetDllLibPdf().PdfFileInfo_get_IncrementalUpdate.argtypes = [c_void_p]
        GetDllLibPdf().PdfFileInfo_get_IncrementalUpdate.restype = c_bool
        ret = GetDllLibPdf().PdfFileInfo_get_IncrementalUpdate(self.Ptr)
        return ret

    @IncrementalUpdate.setter
    def IncrementalUpdate(self, value: bool):
        """
        Sets a value indicating whether [incremental update].
        :param value: True if [incremental update]; otherwise, False.
        """
        GetDllLibPdf().PdfFileInfo_set_IncrementalUpdate.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfFileInfo_set_IncrementalUpdate(self.Ptr, value)

    @property
    def CrossReferenceType(self) -> 'PdfCrossReferenceType':
        """
        Gets or sets the type of PDF cross-reference.
        :return: The type of PDF cross-reference.
        """
        GetDllLibPdf().PdfFileInfo_get_CrossReferenceType.argtypes = [c_void_p]
        GetDllLibPdf().PdfFileInfo_get_CrossReferenceType.restype = c_int
        ret = GetDllLibPdf().PdfFileInfo_get_CrossReferenceType(self.Ptr)
        objwrapped = PdfCrossReferenceType(ret)
        return objwrapped

    @CrossReferenceType.setter
    def CrossReferenceType(self, value: 'PdfCrossReferenceType'):
        """
        Sets the type of PDF cross-reference.
        :param value: The type of PDF cross-reference.
        """
        GetDllLibPdf().PdfFileInfo_set_CrossReferenceType.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfFileInfo_set_CrossReferenceType(self.Ptr, value.value)

    @property
    def TaggedPdf(self) -> bool:
        """
        Gets the value indicating whether the PDF document is tagged one or not.
        :return: True if PDF document is tagged, otherwise False.
        """
        GetDllLibPdf().PdfFileInfo_get_TaggedPdf.argtypes = [c_void_p]
        GetDllLibPdf().PdfFileInfo_get_TaggedPdf.restype = c_bool
        ret = GetDllLibPdf().PdfFileInfo_get_TaggedPdf(self.Ptr)
        return ret

==> Spire.Pdf-10.12.1-py3-none-win_amd64.whl: spire/pdf/PdfFileInfo.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfFileInfo(SpireObject):
    """
    This class represents a set of the properties that define the internal structure of PDF file.
    """

    @property
    def Version(self) -> 'PdfVersion':
        """
        Gets or sets the version of the PDF document.
        :return: The document version.
        """
        GetDllLibPdf().PdfFileInfo_get_Version.argtypes = [c_void_p]
        GetDllLibPdf().PdfFileInfo_get_Version.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfFileInfo_get_Version,self.Ptr)
        objwrapped = PdfVersion(ret)
        return objwrapped

    @Version.setter
    def Version(self, value: 'PdfVersion'):
        """
        Sets the version of the PDF document.
        :param value: The document version.
        """
        GetDllLibPdf().PdfFileInfo_set_Version.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfFileInfo_set_Version,self.Ptr, value.value)

    @property
    def IncrementalUpdate(self) -> bool:
        """
        Gets or sets a value indicating whether [incremental update].
        :return: True if [incremental update]; otherwise, False.
        """
        GetDllLibPdf().PdfFileInfo_get_IncrementalUpdate.argtypes = [c_void_p]
        GetDllLibPdf().PdfFileInfo_get_IncrementalUpdate.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfFileInfo_get_IncrementalUpdate,self.Ptr)
        return ret

    @IncrementalUpdate.setter
    def IncrementalUpdate(self, value: bool):
        """
        Sets a value indicating whether [incremental update].
        :param value: True if [incremental update]; otherwise, False.
        """
        GetDllLibPdf().PdfFileInfo_set_IncrementalUpdate.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfFileInfo_set_IncrementalUpdate,self.Ptr, value)

    @property
    def CrossReferenceType(self) -> 'PdfCrossReferenceType':
        """
        Gets or sets the type of PDF cross-reference.
        :return: The type of PDF cross-reference.
        """
        GetDllLibPdf().PdfFileInfo_get_CrossReferenceType.argtypes = [c_void_p]
        GetDllLibPdf().PdfFileInfo_get_CrossReferenceType.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfFileInfo_get_CrossReferenceType,self.Ptr)
        objwrapped = PdfCrossReferenceType(ret)
        return objwrapped

    @CrossReferenceType.setter
    def CrossReferenceType(self, value: 'PdfCrossReferenceType'):
        """
        Sets the type of PDF cross-reference.
        :param value: The type of PDF cross-reference.
        """
        GetDllLibPdf().PdfFileInfo_set_CrossReferenceType.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfFileInfo_set_CrossReferenceType,self.Ptr, value.value)

    @property
    def TaggedPdf(self) -> bool:
        """
        Gets the value indicating whether the PDF document is tagged one or not.
        :return: True if PDF document is tagged, otherwise False.
        """
        GetDllLibPdf().PdfFileInfo_get_TaggedPdf.argtypes = [c_void_p]
        GetDllLibPdf().PdfFileInfo_get_TaggedPdf.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfFileInfo_get_TaggedPdf,self.Ptr)
        return ret
